@@ -1,4 +1,4 @@
-# Copyright 2016-2022 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
+# Copyright 2016-2023 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
 # ReFrame Project Developers. See the top-level LICENSE file for details.
 #
 # SPDX-License-Identifier: BSD-3-Clause
@@ -829,7 +829,10 @@ def make_test(name, bases, body, methods=None, **kwargs):
 
     .. code-block:: python
 
-       hello_cls = rfm.make_test(
+       from reframe.core.meta import make_test
+
+
+       hello_cls = make_test(
            'HelloTest', (rfm.RunOnlyRegressionTest,),
            {
                'valid_systems': ['*'],
@@ -859,6 +862,7 @@ def make_test(name, bases, body, methods=None, **kwargs):
     .. code-block:: python
 
        import reframe.core.builtins as builtins
+       from reframe.core.meta import make_test
 
 
        def set_message(obj):
@@ -867,7 +871,7 @@ def make_test(name, bases, body, methods=None, **kwargs):
        def validate(obj):
            return sn.assert_found(obj.message, obj.stdout)
 
-       hello_cls = rfm.make_test(
+       hello_cls = make_test(
            'HelloTest', (rfm.RunOnlyRegressionTest,),
            {
                'valid_systems': ['*'],
