@@ -1,4 +1,4 @@
-# Copyright 2016-2022 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
+# Copyright 2016-2023 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
 # ReFrame Project Developers. See the top-level LICENSE file for details.
 #
 # SPDX-License-Identifier: BSD-3-Clause
@@ -191,8 +191,9 @@ class SlurmJobScheduler(sched.JobScheduler):
                 self._format_option(job.exclusive_access, '--exclusive')
             )
 
-        if self._use_nodes_opt:
-            num_nodes = job.num_tasks // job.num_tasks_per_node
+        if self._use_nodes_opt and job.num_tasks is not None:
+            num_tasks_per_node = job.num_tasks_per_node or 1
+            num_nodes = job.num_tasks // num_tasks_per_node
             preamble.append(self._format_option(num_nodes, '--nodes={0}'))
 
         if job.use_smt is None:
