@@ -1,4 +1,4 @@
-# Copyright 2016-2021 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
+# Copyright 2016-2023 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
 # ReFrame Project Developers. See the top-level LICENSE file for details.
 #
 # SPDX-License-Identifier: BSD-3-Clause
@@ -48,15 +48,15 @@ class PrettyPrinter:
 
         status_stripped = status.strip()
         if self.colorize:
-            if status_stripped == 'SKIP':
+            if status_stripped in ('DRY', 'SKIP'):
                 status = color.colorize(status, color.YELLOW)
-            elif status_stripped in ['FAIL', 'FAILED', 'ERROR']:
+            elif status_stripped in ('FAIL', 'FAILED', 'ERROR'):
                 status = color.colorize(status, color.RED)
             else:
                 status = color.colorize(status, color.GREEN)
 
         final_msg = f'[ {status} ] '
-        if status_stripped in ['OK', 'SKIP', 'FAIL']:
+        if status_stripped in ('OK', 'SKIP', 'FAIL'):
             self._progress_count += 1
             width = len(str(self._progress_total))
             padded_progress = str(self._progress_count).rjust(width)
@@ -75,3 +75,11 @@ class PrettyPrinter:
     def __getattr__(self, attr):
         # delegate all other attribute lookup to the underlying logger
         return getattr(logging.getlogger(), attr)
+
+    def __setattr__(self, attr, value):
+        # Delegate colorize setting to the backend logger
+        if attr == 'colorize':
+            logging.getlogger().colorize = value
+            self.__dict__['colorize'] = value
+        else:
+            super().__setattr__(attr, value)
